@@ -55,6 +55,8 @@ enum eCommandKind {
     kEach,
     kForeach,
 //    kParse,
+    kAbs,
+    kFAbs,
     kInnerCommand,
     kCommand 
 };
